@@ -17,14 +17,15 @@
 #endif
 
 BookView::BookView(QWidget *parent):
-        QWebView(parent), contentIndex(-1), mBook(0), restore(true), restorePos(0),
-        loadFinished(false)
+    QWebView(parent), contentIndex(-1), mBook(0),
+    restore(true), restorePos(0), loadFinished(false)
 {
     settings()->setAttribute(QWebSettings::AutoLoadImages, true);
     settings()->setAttribute(QWebSettings::JavascriptEnabled, true);
     settings()->setAttribute(QWebSettings::PluginsEnabled, false);
     settings()->setAttribute(QWebSettings::ZoomTextOnly, true);
-    settings()->setAttribute(QWebSettings::LocalContentCanAccessRemoteUrls, false);
+    settings()->setAttribute(QWebSettings::LocalContentCanAccessRemoteUrls,
+                             false);
     page()->setContentEditable(false);
 
 #if defined(Q_WS_MAEMO_5)
@@ -78,6 +79,7 @@ void BookView::loadContent(int index)
     }
     else {
         loadFinished = false;
+        emit chapterLoadStart(index);
         load(QUrl(contentFile));
     }
     contentIndex = index;
@@ -146,7 +148,7 @@ void BookView::onLoadFinished(bool ok)
     loadFinished = true;
     addNavigationBar();
     onSettingsChanged("scheme");
-    emit chapterLoaded(contentIndex);
+    emit chapterLoadEnd(contentIndex);
     if (restore) {
         restore = false;
         if (ok && mBook) {
@@ -165,13 +167,11 @@ void BookView::onSettingsChanged(const QString &key)
     }
     else if (key == "font") {
         QString face = Settings::instance()->value("font").toString();
-        qDebug() << "" << face;
         settings()->setFontFamily(QWebSettings::StandardFont, face);
     }
     else if (key == "scheme") {
         QWebFrame *frame = page()->mainFrame();
         QString scheme = Settings::instance()->value("scheme").toString();
-        qDebug() << "" << scheme;
         if ((scheme != "day") && (scheme != "night") && (scheme != "sand") &&
             (scheme != "default")) {
             scheme = "default";
@@ -181,8 +181,6 @@ void BookView::onSettingsChanged(const QString &key)
         QString scriptText = script.readAll();
         script.close();
         QVariant ret = frame->evaluateJavaScript(scriptText);
-        qDebug() << "" << script.fileName() << ":" << scriptText;
-        qDebug() << "" << ret;
     }
 }
 
