@@ -4,28 +4,22 @@
 #include <QDialog>
 #include <QString>
 #include <QModelIndexList>
+#include <QMainWindow>
 
-class QMainWindow;
-class QListWidget;
-class QListWidgetItem;
+class QListView;
 class QPushButton;
+class QModelIndex;
+class QCloseEvent;
 class Book;
 class InfoWindow;
+class SortedLibrary;
 
-class LibraryDialog: public QDialog
+class LibraryDialog: public QMainWindow
 {
     Q_OBJECT
 
 public:
     explicit LibraryDialog(QWidget *parent = 0);
-    QListWidget *list;
-#ifndef Q_WS_MAEMO_5
-    QPushButton *detailsButton;
-    QPushButton *removeButton;
-    QPushButton *readButton;
-#endif
-    QPushButton *addButton;
-    QString lastDir;
 
 public slots:
     void onAdd();
@@ -34,13 +28,26 @@ public slots:
     void onDetails();
     void onRead();
     void onItemSelectionChanged();
-#endif
+#endif // Q_WS_MAEMO_5
     void onBookAdded();
-    void onItemActivated(QListWidgetItem *item);
+    void onItemActivated(const QModelIndex &index);
     void onCurrentBookChanged();
 
+protected:
+    void closeEvent(QCloseEvent *event);
+
 private:
     QString createItemText(const Book *book);
+    void setSelected(const QModelIndex &index);
+    QModelIndex selected() const;
+    QListView *list;
+    SortedLibrary *sortedLibrary;
+#ifndef Q_WS_MAEMO_5
+    QPushButton *detailsButton;
+    QPushButton *removeButton;
+    QPushButton *readButton;
+#endif // Q_WS_MAEMO_5
+    QPushButton *addButton;
 };
 
 #endif // LIBRARYDIALOG_H
